//
// File: file.cc
// file class, handles files
//
// Created by: Joni Valtanen <jvaltane@lpt.fi>
// Created on: Wed Nov  3 17:26:03 2004
//

#include "file.h"
#ifdef MACOSX
#define HISCORE_FILE_PATH "sixzee.app/Contents/Resources/"
#else
 #ifdef WIN32
 	#define HISCORE_FILE_PATH ""
 #else
      #define HISCORE_FILE_PATH "/var/games/"
 #endif
#endif

#define HISCORE_FILE "sixzee.scores"

file::file()
{
	yGame = new game;
	hiscores = new hiScore;
}

file::~file()
{
	delete yGame;
	delete hiscores;
}

// checks if config file and creates it if doesn't exist
int file::checkConfig()
{
	ofstream myOFile;
	ifstream myIFile;

#ifndef WIN32	
	char *tmp=getenv("HOME");
	string dir(tmp);
	dir += "/.sixzee";
	configFile = tmp;
	configFile += "/.sixzee/config";
#else
    configFile = "config";
#endif

	
	myIFile.open(configFile.c_str(), ios::in|ios::out);
	if(myIFile.good())
	{
		cout << "Config :: file: " << configFile <<  endl;
	}
	else
	{
        #ifndef WIN32
		if(mkdir(dir.c_str(),00777) < 0 )
			return 3;
		#endif
		myOFile.open(configFile.c_str(), ios::trunc);
		
		myOFile << "fullscreen=0" << endl;
		myOFile << "pns0=Player1" << endl;
		myOFile << "pns1=Player2" << endl;
		myOFile << "pns2=Player3" << endl;
		myOFile << "pns3=Player4" << endl;
		myOFile << "pons0=1"<< endl;
		myOFile << "pons1=1"<< endl;
		myOFile << "pons2=0"<< endl;
		myOFile << "pons3=0"<< endl;
		
		cout << "Config :: creating dir and/or file: " << configFile <<  endl;
		myOFile.close();
	}
	myIFile.close();
	return 0;
}

//reads config file
void file::readConfig()
{
	int i;
	ifstream myFile;
	char buf[MAX_TEXT_FILE];
	char* buf2;
	int fs=7,po[MAX_PLAYERS];
	char pn[MAX_PLAYERS][MAX_TEXT_REALLY];
	
	myFile.open(configFile.c_str());
	while(myFile.peek() !=EOF)
	{
		myFile.getline(buf, MAX_TEXT_FILE, '\n');
		for(i=0;i < strlen(buf) && buf[i]!='='; i++);
		if(buf[i]=='=')
		{
			buf2 = &buf[i+1];
			buf[i] = 0;
			if(!strcmp(buf, "fullscreen"))
				sscanf(buf2, "%i", &fs );
			else if(!strcmp(buf, "pns0"))
				strcpy(pn[0],buf2); // buf, "%i", fs );
			else if(!strcmp(buf, "pns1"))
				strcpy(pn[1],buf2); // buf, "%i", fs );
			else if(!strcmp(buf, "pns2"))
				strcpy(pn[2],buf2); // buf, "%i", fs );
			else if(!strcmp(buf, "pns3"))
				strcpy(pn[3],buf2); // buf, "%i", fs );
			else if(!strcmp(buf, "pons0"))
				sscanf(buf2, "%i", &po[0] );
			else if(!strcmp(buf, "pons1"))
				sscanf(buf2, "%i", &po[1] );
			else if(!strcmp(buf, "pons2"))
				sscanf(buf2, "%i", &po[2] );
			else if(!strcmp(buf, "pons3"))
				sscanf(buf2, "%i", &po[3] );
		}

	}
	myFile.close();

#ifdef DEBUG
	cout << fs << endl;
	
	cout << pn[0] << endl;
	cout << pn[1] << endl;
	cout << pn[2] << endl;
	cout << pn[3] << endl;
	
	cout << po[0] << endl;
	cout << po[1] << endl;
	cout << po[2] << endl;
	cout << po[3] << endl << endl;
#endif
	
	yGame->setConfig(fs,po,(const char *)pn);	
}

//writes config file
void file::writeConfig()
{
	ofstream myOFile;
	int fs;
	bool po[MAX_PLAYERS];
	char *pn[MAX_PLAYERS];
	int i;
	
	fs = yGame->getFullscreen();
	for(i=0; i<MAX_PLAYERS; i++)
	{
		po[i] = yGame->playerIsOnGame(i);
		pn[i] = yGame->getName(i);
	}
	
	myOFile.open(configFile.c_str(), ios::trunc);
		
	if(myOFile.good())
	{
		myOFile << "fullscreen="<< (int)fs << endl;
		myOFile << "pns0=" << pn[0]<< endl;
		myOFile << "pns1=" << pn[1] << endl;
		myOFile << "pns2=" << pn[2] << endl;
		myOFile << "pns3=" << pn[3] << endl;
		myOFile << "pons0=" << (int)po[0]<< endl;
		myOFile << "pons1=" << (int)po[1]<< endl;
		myOFile << "pons2=" << (int)po[2]<< endl;
		myOFile << "pons3=" << (int)po[3]<< endl;

#ifdef DEBUG

		cout << "fullscreen="<< (int)fs << endl;
		cout << "pns0=" << pn[0]<< endl;
		cout << "pns1=" << pn[1] << endl;
		cout << "pns2=" << pn[2] << endl;
		cout << "pns3=" << pn[3] << endl;
		cout << "pons0=" << (int)po[0]<< endl;
		cout << "pons1=" << (int)po[1]<< endl;
		cout << "pons2=" << (int)po[2]<< endl;
		cout << "pons3=" << (int)po[3]<< endl;
#endif		
		cout << "Configuration saved. file: " << configFile <<  endl;
	}
	myOFile.close();


}

// out: pointer to the game-class
game *file::getGame()
{
	return yGame;	
}

// out: pointer to the game-class
hiScore *file::getHiscore()
{
	return hiscores;	
}

// ceates hiscore file if mandatory
/*void file::createHiscoreFile()
{
	int i;
	ofstream myOFile;
	string hiscoreFile(HISCORE_FILE_PATH);
	
	hiscoreFile += HISCORE_FILE;
	
	myOFile.open(hiscoreFile.c_str(), ios::trunc);
	if(myOFile.good())
	{
		cout << "hiscores: " << hiscoreFile << endl;
	}
	else
	{
		for(i=0;i<MAX_HISCORES;i++)
		{
			myOFile << "Joni" << endl;
			myOFile << "0" << endl;
		}
	}
	myOFile.close();
}
*/

//reads hiscores
void file::readHiscores()
{
	int i=0;
	ifstream myFile;
	string hiscoreFile(HISCORE_FILE_PATH);
	char buf[2][MAX_TEXT_FILE+1];
	
	hiscoreFile = hiscoreFile + HISCORE_FILE;

	myFile.open(hiscoreFile.c_str());
	while(myFile.peek() !=EOF)
	{
		myFile.getline(buf[0], MAX_TEXT_FILE, '\n');
		myFile.getline(buf[1], MAX_TEXT_FILE, '\n');
//		cout << "name: " << buf[0] << ", score:"  << buf[1] << endl;
		hiscores->setHiscore(buf[0], atoi(buf[1]),i++);
/*		buf[0][0]=0;
		buf[1][0]=0;*/
	}
		
	myFile.close();
	
}

//writes hiscorefile
void file::writeHiscores()
{
	int i;
	ofstream myOFile;
	string hiscoreFile(HISCORE_FILE_PATH);
	
	hiscoreFile += HISCORE_FILE;
	
	myOFile.open(hiscoreFile.c_str(), ios::trunc);
	if(myOFile.good())
	{
		for(i=0;i<MAX_HISCORES;i++)
		{
			myOFile << hiscores->getName(i) << endl;
			myOFile << hiscores->getScore(i) << endl;
		}
	}
	myOFile.close();
	
}
