//
// File: itextbox.cc
// inputtextbox class for SDL
//
// Created by: Joni Valtanen <jvaltane@lpt.fi>
// Created on: Tue Nov  2 14:51:36 2004
//
//
// GNU General Public Licence version 2 - Read COPYING from the package
//

#include "itextbox.h"


itextbox::itextbox()
{
	// TODO: put constructor code here
}

itextbox::itextbox( int x_pos, int y_pos, int tsize,const char* bg)
{
	string theme = "/default";

#ifndef WIN32
	string datadir = DATADIR + theme;
#else
	string datadir = DATADIR_WIN32 + theme;
#endif
	fn_font1 = datadir + FONT1_NAME;
	
	fontcolor.r = 0x00;
	fontcolor.g = 0x00;
	fontcolor.b = 0x00;
	fontcolor.unused = 0x00;

	TTF_Init();

	font=TTF_OpenFont(fn_font1.c_str(), tsize);
	TTF_SetFontStyle(font, TTF_STYLE_NORMAL);
	
	active = false;
	x = x_pos;
	y = y_pos;	
	background = IMG_Load(bg);
	size = tsize;
	

}


itextbox::~itextbox()
{
	TTF_CloseFont(font);
	TTF_Quit();
	
	if(background)
		SDL_FreeSurface(background);
}

void itextbox::update(SDL_Surface* destination)
{
	SDL_Rect dstrect;
	SDL_Surface* textsurface;
	SDL_Color* fc = &fontcolor;
	
	textsurface = TTF_RenderText_Blended( font, text, *fc);
	
	dstrect.x = x;
	dstrect.y = y;

	dstrect.w = background->w;
	dstrect.h = background->h;
	
	SDL_BlitSurface( background, NULL, destination, &dstrect);
	
	if(strlen(text) > 0)
	{
		dstrect.w = textsurface->w;
		dstrect.h = textsurface->h;

		SDL_BlitSurface( textsurface, NULL, destination, &dstrect);
	}
	
	dstrect.w = background->w;
	dstrect.h = background->h;
	
	SDL_UpdateRect(destination, dstrect.x,	dstrect.y, dstrect.w, dstrect.h );
	
	SDL_FreeSurface(textsurface);
		
}

void itextbox::onMouseClick(int mx, int my, SDL_Surface *screen)
{
	active=false;

	if( (mx > x) && (mx < (x+background->w) ) && 
		(my > y) && (my < (y+background->h) ))
		active=true;
	else
		update(screen);
}

void itextbox::edit(SDL_KeyboardEvent* key, SDL_Surface* screen)
{
	int len = strlen( text );

	if(active)
	{

		if(key->keysym.sym == SDLK_BACKSPACE)
		{
			//if(strlen(text) > 0 )
			if(len > 0 )
				text[len-1] = 0;	
			//	text[strlen(text)-1] = 0;	
		}
		else if(key->keysym.sym == SDLK_DELETE)
		{
				text[0] = 0;	
		}
		else if(key->keysym.sym == SDLK_RETURN)
		{
				active = false;	
		}
		else if( len < ( MAX_TEXT_ITEXTBOX - 1) ) 
		{
			
			//strcat( text, (char *)&key->keysym.unicode );
			text[ len ] = key->keysym.unicode;
		}
		update(screen);
	}
}

char *itextbox::getText()
{
	return text;
}

void itextbox::setText(char* eText)
{
	strcpy(text, eText);
}

void itextbox::isActive(SDL_Surface* screen)
{
	SDL_Rect dstrect;
	SDL_Surface* textsurface;
	SDL_Color* fc = &fontcolor;

	if(active)
	{
		textsurface = TTF_RenderText_Blended( font, text, *fc);
	
		dstrect.x = x;
		dstrect.y = y;

		if(strlen(text) > 0)
		{
			dstrect.w = textsurface->w;
			dstrect.h = textsurface->h;			
		}
		else
		{
			dstrect.w = 0;
			dstrect.h = 0;			
		}
		
		dstrect.x += (dstrect.w + 1);
		dstrect.w = 2;		
		dstrect.y +=4;
		dstrect.h =21;
		update(screen);
		
		SDL_FillRect(screen, &dstrect, 0x0000);
		SDL_UpdateRect(screen, dstrect.x,	dstrect.y, dstrect.w, dstrect.h );
			
	}
}
